// 云函数入口文件
const cloud = require('wx-server-sdk')

cloud.init({
  env: cloud.DYNAMIC_CURRENT_ENV
})
const db = cloud.database();
// 云函数入口函数
exports.main = async (event, context) => {

  switch (event.action) {
    case 'add': {
      return addCategory(event)
    }
    case 'del': {
      return delCategory(event)
    }
    case 'edit': {
      return editCategory(event)
    }
    case 'find': {
      return findCategory(event)
    }
    case 'findCategoryById':{
      return findCategoryById(event)
    }
    default: {
      return
    }
  }
}

async function addCategory(event){
  try{
    const result = await db.collection('foodCategory').add({
      data:{
        category_type:event.category_type,
        name:event.name,
        order:event.order,
        create_time:new Date()
      }
    });
    if(result.errMsg == 'collection.add:ok'){
      return {
        code:1,
        data:null,
        msg:'添加成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '添加失败'
    }
  }catch(e){
    return {
      code: 0,
      data: null,
      msg: '添加失败'
    }
  }
}
async function delCategory(event) {
  try{
    const result = await db.collection('foodCategory').doc(event._id).remove();
    if (result.errMsg == 'document.remove:ok') {
      return {
        code: 1,
        data: null,
        msg: '删除成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '删除失败'
    }
  }catch(e){
    return {
      code: 0,
      data: null,
      msg: '删除失败'
    }
  }
}
async function editCategory(event) {
  try {
    const result = await db.collection('foodCategory').doc(event._id).update({
      data: {
        category_type: event.category_type,
        name: event.name,
        update_time: new Date()
      }
    });
    if (result.errMsg == 'document.update:ok') {
      return {
        code: 1,
        data: null,
        msg: '更新成功'
      }
    }
    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  } catch (e) {
    return {
      code: 0,
      data: null,
      msg: '更新失败'
    }
  }
}
async function findCategory(event) {
   try{
     const result = await db.collection('foodCategory').get();
     if(result.errMsg == 'collection.get:ok'){
       return {
         code:1,
         data:result.data,
         msg:"查询成功"
       }
     }
     return {
       code: 0,
       data: null,
       msg: "查询失败"
     }
   }catch(e){
     return {
       code: 0,
       data: null,
       msg: "查询失败"
     }
   }
}

async function findCategoryById(event) {
  try {
    const result = await db.collection('foodCategory').doc(event._id).get();
    if (result.errMsg == 'document.get:ok') {
      return {
        code: 1,
        data: result.data,
        msg: "查询成功"
      }
    }
    return {
      code: 0,
      data: null,
      msg: "查询失败"
    }
  } catch (e) {
    return {
      code: 0,
      data: null,
      msg: "查询失败"
    }
  }
}