// miniprogram/pages/productlist/productlist.js
Page({

  /**
   * 页面的初始数据
   */
  data: {
    showDialog: false,
    cart:null,  // 购物车信息
    foodList:[],
    food:{}
  },
  goOrder(){
    wx.setStorageSync('cart', this.cart);
    wx.navigateTo({
      url: '../confirm-order/confirm-order',
    })
  },
  addOne(){
    console.log('添加一份');
  },
  addCart(e){
    const that =this;
    var foodId = e.currentTarget.dataset.foodId;
    wx.cloud.callFunction({
      name:'cart',
      data:{
        action:'addCart',
        foodId,
        out_count:1,
      },
      success(res){
        if(res.result.code == 1){
          that.foodList.map(val => {
            if(val._id == foodId){
              val.out_count = 1
            }
          });
          if(that.food) that.food.out_count = 1;
          that.setData({
            foodList: that.foodList,
            food:that.food
          })
          that.getCart();
        }
      }
    })
  },
  getCart(){
    const that = this;
    wx.cloud.callFunction({
      name:'cart',
      data: { action:'findAll'},
      success(res){
        console.log(res);
        if(res.result.code == 1){
          var carts = res.result.data;
          that.cart = carts[0] || null;
           // 遍历购物车中foodlist 同时遍历获取foodlist
           // 如果两个id相同，更新foodlist out_count值
          if (carts.length !==0){
             that.cart.foodList.forEach(function (cFood) {
               that.foodList.forEach(function (food) {
                 if (cFood._id == food._id) {
                   food.out_count = cFood.out_count;
                 }
               })
             })
            
           }
          that.setData({
            foodList: that.foodList,
            cart: that.cart
          })
          console.log(that.foodList);
          
        }
      }
    })
  },
  /**
   * 获取分类信息 加载第一分类下的食品信息
   */
  getCategories(){
    const that = this;
    const categories = wx.getStorageSync('categories');
    if (categories){
      that.getFood(categories[0].category_type, {
        success(res) {
          that.foodList = res.result.data;
          that.setData({
            categories: categories,
            foodList: res.result.data,
            tabSelected: categories[0]._id,
          })
          that.getCart(res.result.data);
        }
      });
    }else{
      wx.cloud.callFunction({
        name: 'categories',
        data: { action:'find'},
        success: (res) => {
          if(res.result.code == 1){
            // 默认加载第一个分类的数据
            const categories = res.result.data;
            wx.setStorageSync('categories', categories);
            that.getFood(categories[0].category_type, {
              success(res) {
                that.foodList = res.result.data;
                that.setData({
                  categories: categories,
                  foodList: res.result.data,
                  tabSelected: categories[0]._id,
                })
                that.getCart(res.result.data);
              }
            });
          }
        },
        fail: () => {
          console.error('获取分类失败');
        }
      })
    }
  },
  handleZanStepperMinus(e){
    console.log(e);
    var foodId = e.currentTarget.dataset.foodId;
    var stepper = e.currentTarget.dataset.stepper-1;
    if (stepper == 0) {
      this.delCart(foodId);
    } else {
      this.updateCart(foodId, stepper);
    }
  },
  handleZanStepperPlus(e){
    console.log(e);
    var foodId = e.currentTarget.dataset.foodId;
    var stepper = e.currentTarget.dataset.stepper+1;
    this.updateCart(foodId,stepper);
  },

  delCart(foodId){
    const that = this;
    wx.cloud.callFunction({
      name:'cart',
      data:{
        action:'deleteCartOne',
        cartId: that.cart._id,
        foodId,
      },
      success(res){
        if(res.result.code == 1){
          that.foodList.map(val => {
            if (val._id == foodId) {
              val.out_count = 0
            }
          });
          if(that.food) that.food.out_count = 0;
          that.setData({
            foodList: that.foodList,
            food: that.food
          })
          that.getCart();
        }
      }
    })
  },

  /**
   * 更新购物车信息
   */
  updateCart(foodId, stepper){
    const that = this;
    wx.cloud.callFunction({
      name:'cart',
      data:{
        action: 'updateCart',
        cartId: that.cart._id,
        foodId,
        out_count: stepper
      },
      success(res){
        if(res.result.code == 1){
          that.foodList.map(val => {
            if (val._id == foodId) {
              val.out_count = stepper
            }
          });
          if (that.food) that.food.out_count = stepper;
          that.setData({
            foodList: that.foodList,
            food:that.food
          })
          that.getCart();
        }
      }
    })
  },

 /**
  * 根据category_type获取商品信息
  */
  getFood(category_type,callback={}){
    const that = this;
    wx.cloud.callFunction({
      name: 'foodList',
      data: {
        category_type: category_type,
        action:'findListByCategoryType'
      },
      success: (res) => {
        if(res.result.code == 1){
          if (typeof callback.success == 'function') callback.success(res);
        }
      },
      fail: () => console.error('获取食品失败')
    })
  },

  /**
   * 分类绑定点击事件
   */
  changeCategory(e){
    const that = this;
    var category_type = e.currentTarget.dataset.categoryType;
    var category_id = e.currentTarget.dataset.categoryId;
    console.log(category_type);
    this.getFood(category_type,{
      success(res){
        that.foodList = res.result.data;
        that.setData({
          foodList: res.result.data,
          tabSelected: category_id,
        })
        that.getCart(res.result.data);
      }
    });
  },
  openDialog: function (e) {
    const that = this;
    var foodId = e.currentTarget.dataset.foodId;
    wx.cloud.callFunction({
      name:'foodList',
      data:{
        action:'find',
        _id: foodId
      },
      success(res){
        if(res.result.code == 1){
          that.food = res.result.data;
          that.foodList.forEach(val=>{
            if (val._id == that.food._id){
              that.food.out_count = val.out_count;
            }
          })
          console.log(that.food);
          that.setData({
            food: that.food,
            istrue: true
          })
        }
      },
      fail(){console.log('获取失败')}
    })
  },
  closeDialog: function () {
    this.food = null;
    this.setData({
      istrue: false
    })
  },

  openCart(){
    if(this.cart == null){
      wx.showToast({
        title: '请选择商品',
        icon:''
      })
      return;
    }
    this.setData({
      showCartBox: true
    })
  },
  closeCartBox(){
    this.setData({
      showCartBox: false
    })
  },
  deleteAllCart(){
    const that = this;
    wx.cloud.callFunction({
      name:'cart',
      data: { action:'deleteAllCart',cartId:this.cart._id},
      success(res){
        if(res.result.code == 1){
          that.foodList.map(val=>val.out_count =0);
          that.setData({
            foodList:that.foodList,
            cart:null,
            showCartBox: false
          })
          that.getCart()
        }
      },
      fail(){console.error("删除失败")}
    })
  },
  /**
   * 生命周期函数--监听页面加载
   */
  onLoad: function (options) {
    this.getCategories();
  },

  /**
   * 生命周期函数--监听页面初次渲染完成
   */
  onReady: function () {

  },

  /**
   * 生命周期函数--监听页面显示
   */
  onShow: function () {

  },

  /**
   * 生命周期函数--监听页面隐藏
   */
  onHide: function () {

  },

  /**
   * 生命周期函数--监听页面卸载
   */
  onUnload: function () {

  },

  /**
   * 页面相关事件处理函数--监听用户下拉动作
   */
  onPullDownRefresh: function () {

  },

  /**
   * 页面上拉触底事件的处理函数
   */
  onReachBottom: function () {

  },

  /**
   * 用户点击右上角分享
   */
  onShareAppMessage: function () {

  }
})